/*
 * BSD Telephony Of Mexico "Tormenta" card LINUX driver, version 1.6 1/9/01
 * 
 * Working with the "Tormenta ISA" Card 
 * 
 *
 *   Part of the "Zapata" Computer Telephony Technology.
 *
 *   See http://www.bsdtelephony.com.mx
 *
 *
 *  The technologies, software, hardware, designs, drawings, scheumatics, board
 *  layouts and/or artwork, concepts, methodologies (including the use of all
 *  of these, and that which is derived from the use of all of these), all other
 *  intellectual properties contained herein, and all intellectual property
 *  rights have been and shall continue to be expressly for the benefit of all
 *  mankind, and are perpetually placed in the public domain, and may be used,
 *  copied, and/or modified by anyone, in any manner, for any legal purpose,
 *  without restriction.
 */

#ifndef _ZTCFG_H
#define _ZTCFG_H

#define CONFIG_FILENAME ZAPTEL_CONFIG
#define MASTER_DEVICE   "/dev/zap/ctl"
#endif
